import { EmitterSubscription, NativeEventEmitter, NativeModules, Platform } from 'react-native';

const LINKING_ERROR =
  `The package 'react-native-theorem-reach-ld' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo managed workflow\n';

const TheoremReachLd = NativeModules.TheoremReachLd
  ? NativeModules.TheoremReachLd
  : new Proxy(
      {},
      {
        get() {
          throw new Error(LINKING_ERROR);
        },
      }
    );

const eventEmitter = new NativeEventEmitter(TheoremReachLd);

type EventType = 'onRewardCenterOpened' | 'onRewardCenterClosed'

export const addListener = (type: EventType, handler: (value: any) => void): EmitterSubscription => {
  return eventEmitter.addListener(type, handler);
};

export function show(placementId?: string) {
  TheoremReachLd.show(placementId);
}

export function initialize({ apiKey, userId } : { apiKey:string, userId:string }) {
  TheoremReachLd.initialize(apiKey, userId);
}

export function isSurveyAvailable(): Promise<boolean> {
  return TheoremReachLd.isSurveyAvailable();
}
